==> gwt-bean-validators-engine-1.11.12.jar: de/knightsoftnet/validators/client/GwtMessageInterpolator.java <==
/*
 * Copyright 2010 Google Inc. Copyright 2016 Manfred Tremmel
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.validators.client;

import de.knightsoftnet.validators.client.impl.NullUserValidationMessageResolver;

/**
 * Simple GWT {@link javax.validation.MessageInterpolator}.
 */
public class GwtMessageInterpolator extends AbstractBaseMessageInterpolator {
  // This class only has the parts the need to overridden for GWT

  /**
   * Creates a {@link javax.validation.MessageInterpolator MessageInterpolator} MessageInterpolator
   * that uses the default {@link UserValidationMessagesResolver}.
   */
  public GwtMessageInterpolator() { // NOPMD
    this(new NullUserValidationMessageResolver());
  }

  /**
   * Creates a {@link javax.validation.MessageInterpolator MessageInterpolator} using the supplied
   * {@link UserValidationMessagesResolver}.
   *
   * @param userValidationMessagesResolver user validation messages resolver
   */
  public GwtMessageInterpolator(
      final UserValidationMessagesResolver userValidationMessagesResolver) {
    super(userValidationMessagesResolver);
  }
}

==> gwt-bean-validators-engine-2.1.3.jar: de/knightsoftnet/validators/client/GwtMessageInterpolator.java <==
/*
 * Copyright 2010 Google Inc. Copyright 2016 Manfred Tremmel
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.validators.client;

import de.knightsoftnet.validators.client.impl.NullUserValidationMessageResolver;

/**
 * Simple GWT {@link jakarta.validation.MessageInterpolator}.
 */
public class GwtMessageInterpolator extends AbstractBaseMessageInterpolator {
  // This class only has the parts the need to overridden for GWT

  /**
   * Creates a {@link jakarta.validation.MessageInterpolator MessageInterpolator}
   * MessageInterpolator that uses the default {@link UserValidationMessagesResolver}.
   */
  public GwtMessageInterpolator() { // NOPMD
    this(new NullUserValidationMessageResolver());
  }

  /**
   * Creates a {@link jakarta.validation.MessageInterpolator MessageInterpolator} using the supplied
   * {@link UserValidationMessagesResolver}.
   *
   * @param userValidationMessagesResolver user validation messages resolver
   */
  public GwtMessageInterpolator(
      final UserValidationMessagesResolver userValidationMessagesResolver) {
    super(userValidationMessagesResolver);
  }
}
